import { csv, select } from 'd3';
import { scatterPlot } from './scatterPlot';
//Attaching csv URL
const csvUrl = [
  'https://gist.githubusercontent.com/',
  'Sharanya1307/', // User
  'b060666a669c5d4e1d9e537b8d705686/', // Id of the Gist
  'raw/c1703d34c2f35861280c278fd01e8ddc49f8e979/', // commit
  'Iris_dataset.csv', // File name

].join('');
const parseRow = (d) => {
  d.sepal_length = +d.sepal_length;
  d.sepal_width = +d.sepal_width;
  d.petal_length = +d.petal_length;
  d.petal_width = +d.petal_width;
  return d;
};
//Width and Height are determined
//These values are constant and are set to 
//the windows innerHeight and innerWidth
const width = window.innerWidth;
const height = window.innerHeight;
//appending the svg to body
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

//Creating the async()
//The scatterplot is created 
const main = async () => {
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d.petal_width)
    .yValue((d) => d.sepal_length)
  	.rxValue((d) => d.sepal_width)
    .ryValue((d) => d.petal_length)
    .speciesValue((d) => d.species)
  	.symbolValue((d) => d.species)
    .margin({
      top: 20,
      right: 20,
      bottom: 40,
      left: 60,
    })
    .radius(5);

  svg.call(plot);
//Columns are initialized below
  const columns = [
    'petal_width',
    'sepal_width',
    'petal_length',
    'sepal_length',
  ];
  
//Creating on-page text display
//Showing colors based on species
svg.append('rect')
  .attr('x', 120)
  .attr('y', 50)
  .attr('width', 150)
  .attr('height', 100)
  .attr('stroke', 'blue')
  .attr('fill', '#F3F3F3');
svg.append("text").attr("x", 300).attr("y", 20).text("Reusable D3 Iris Scatter Plot").style("font-size", "40px").attr("alignment-baseline","middle").style('fill', '#2F4F4F').style('font-weight', 'bold')
svg.append("text").attr("x", 150).attr("y", 70).text("Iris-setosa").style("font-size", "20px").style('fill', '#ADFF2F').style("font-family", "calibri").attr("alignment-baseline","middle")
svg.append("text").attr("x", 150).attr("y", 100).text("Iris-versicolor").style("font-size", "20px").style('fill', '#008080').style("font-family", "calibri").attr("alignment-baseline","middle")
svg.append("text").attr("x", 150).attr("y", 130).text("Iris-virginica").style("font-size", "20px").style('fill', '#FF4500').style("font-family", "calibri").attr("alignment-baseline","middle")

//Changing the scatterplot after a specific time
  let i = 0;
  setInterval(() => {
    plot.xValue((d) => d[columns[i % columns.length]]);
    svg.call(plot);
    i++;
    
  }, 2000);
};
main();





